data = {
    'category': [
        'goal',
        'concept',
        'question'
    ],
    'system': [
        'project',
        'structure',
        'mechanism',
        'organization',
        'person',
        'process',
        'api'
    ],
    'method': [
        'idea',
        'principle',
        'function',
        'invention',
        'equipment',
        'product',
        'endpoint'
    ],
    'operation': [
        'CATEGORY',
        'call',
        'call:query',
        'order',
        'order:buy',
        'order:sell',
        'order:transfer',
        'order:machining',
        'order:shipment',
        'order:payment',
        'order:contract',
        'task',
        'task:programming',
        'task:engineering',
        'task:manufacturing',
        'task:treatment',
    ],
    'item': [
        'record',
        'document',
        'METHOD',
        'SYSTEM',
        'OPERATION',
        'location',
        'location:address',
        'location:account',
        'location:url'
    ],
}

